Module: AutoSeeding
- Defined in:
- lib/auto-seeding.rb
Constant Summary collapse
- NAME =
'auto-seeding'.freeze
- INFO =
'Auto seeding component for ActiveRecord'.freeze
- DESC =
'A component to auto generate seed data with ActiveRecord using a set of predefined or custom rules respecting models validations'.freeze
- AUTHORS =
[ [ 'Mattia Roccoberton', '[email protected]', 'http://blocknot.es' ] ].freeze
- DATE =
'2017-09-10'.freeze
- VERSION =
[ 0, 1, 4 ].freeze